AttachParam class

Constructors

AttachParam({required Offset targetOffset, required Size targetSize, required Widget selfWidget, required Offset selfOffset, required Size selfSize})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
selfOffset Offset
final
selfSize Size
final
selfWidget Widget
final
targetOffset Offset
final
targetSize Size
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited