FlutterSmartNotifyStyle class
Constructors
Properties
- alertBuilder → Widget Function(String msg)?
-
final
- errorBuilder → Widget Function(String msg)?
-
final
- failureBuilder → Widget Function(String msg)?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- successBuilder → Widget Function(String msg)?
-
final
- warningBuilder → Widget Function(String msg)?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited